summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/render_box.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/rendering/render_box.cpp')
-rw-r--r--khtml/rendering/render_box.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/khtml/rendering/render_box.cpp b/khtml/rendering/render_box.cpp
index e63115361..1dda168c2 100644
--- a/khtml/rendering/render_box.cpp
+++ b/khtml/rendering/render_box.cpp
@@ -622,7 +622,7 @@ void RenderBox::paintBackgroundExtended(TQPainter *p, const TQColor &c, const Ba
sy+=b.y()-cy;
cx=b.x();cy=b.y();cw=b.width();ch=b.height();
}
// restrict painting to tqrepaint-clip
if (cy < clipy) {
ch -= (clipy - cy);
sy += (clipy - cy);
@@ -795,7 +795,7 @@ void RenderBox::position(InlineBox* box, int /*from*/, int /*len*/, bool /*rever
setPos( box->xPos(), box->yPos() );
}
-void RenderBox::tqrepaint(Priority prior)
+void RenderBox::repaint(Priority prior)
{
int ow = style() ? style()->outlineSize() : 0;
if( isInline() && !isReplaced() )
@@ -622,7 +622,7 @@ void RenderBox::paintBackgroundExtended(TQPainter *p, const TQColor &c, const Ba
cx=b.x();cy=b.y();cw=b.width();ch=b.height();
}
- // restrict painting to tqrepaint-clip
+ // restrict painting to repaint-clip
if (cy < clipy) {
ch -= (clipy - cy);